﻿using System;
using System.Collections.Generic;
using System.ComponentModel;
using System.Data;
using System.Drawing;
using System.Linq;
using System.Text;
using System.Windows.Forms;
using Infragistics.UltraChart.Shared.Styles;
using Infragistics.UltraChart.Resources.Appearance;

using Infragistics.Win.UltraWinChart;
using Infragistics.UltraChart.Core.Primitives;
using Infragistics.UltraChart.Shared.Events;
using System.Diagnostics;
using Infragistics.UltraChart.Core;

namespace UltraChart3DPieChart
{
    public partial class Form1 : Form
    {
        List<Box> legendItems = new List<Box>();
        List<Text> legendText = new List<Text>();
        List<Color> defaultFillBrushes = new List<Color>();

        public Form1()
        {
            InitializeComponent();
        }

        private void Form1_Load(object sender, EventArgs e)
        {

            DataTable table = new DataTable();
            table.Columns.Add("Label", typeof(string));
            table.Columns.Add("Value", typeof(double));
            table.Rows.Add("Yes", 220);
            table.Rows.Add("No", 300);
            

            this.ultraChart1.DataSource = table;
            this.ultraChart1.DataBind();

            this.ultraChart1.Legend.Visible = true;
            this.ultraChart1.Legend.FormatString = " <ITEM_LABEL>";
            this.ultraChart1.Legend.SpanPercentage = 22;

            this.ultraChart1.ChartType = ChartType.PieChart3D;
            this.ultraChart1.PieChart3D.BreakAllSlices = true;

            this.ultraChart1.PieChart3D.OthersCategoryPercent = 0;


            Color[] initColor = new Color[] { Color.Red, Color.Gold};
            this.ultraChart1.ColorModel.ModelStyle = Infragistics.UltraChart.Shared.Styles.ColorModels.CustomLinear;
            this.ultraChart1.ColorModel.CustomPalette = initColor;

            this.ultraChart1.Transform3D.XRotation = 45;
            this.ultraChart1.Transform3D.YRotation = 35;
            this.ultraChart1.Transform3D.ZRotation = 1;
            this.ultraChart1.Tooltips.FormatString = "<ITEM_LABEL>: <DATA_VALUE:#> (<PERCENT_VALUE:#0.00>%)";
            this.ultraChart1.PieChart3D.ColumnIndex = 1;
            this.ultraChart1.PieChart3D.RadiusFactor = 82;

            this.ultraChart1.PieChart3D.Labels.Format = PieLabelFormat.Custom;
            this.ultraChart1.PieChart3D.Labels.FormatString = "<ITEM_LABEL>: <DATA_VALUE:#> (<PERCENT_VALUE:#0.00>%)";
            this.ultraChart1.PieChart3D.Labels.LeaderLinesVisible = true;

            ultraChart1.DataItemOver += new Infragistics.UltraChart.Shared.Events.DataItemOverEventHandler(ultraChart1_DataItemOver);
        }

        void ultraChart1_DataItemOver(object sender, Infragistics.UltraChart.Shared.Events.ChartDataEventArgs e)
        {
            for (int i = 0; i < legendItems.Count; i++)
            {
                legendItems[i].PE.Fill = defaultFillBrushes[i];
                legendItems[i].PE.Stroke = Color.DimGray;
            }

            legendItems[e.DataRow].PE.Fill = ultraChart1.Tooltips.HighlightFillColor;
            legendItems[e.DataRow].PE.Stroke = ultraChart1.Tooltips.HighlightOutlineColor;

        }

        private void ultraNumericEditor1_ValueChanged(object sender, EventArgs e)
        {
            this.ultraChart1.PieChart3D.RadiusFactor = (int)ultraNumericEditor1.Value;
        }

        private void ultraChart1_FillSceneGraph(object sender, Infragistics.UltraChart.Shared.Events.FillSceneGraphEventArgs e)
        {
            foreach (Primitive item in e.SceneGraph)
            {
                if (item is Text)
                {
                    Text pl = item as Text;
                    string temp = pl.GetTextString();
                    if (temp.Contains("Yes") && pl.Path != null && pl.Path.ToLower().IndexOf("legend") != -1)
                    {
                        pl.PE.Fill = Color.Red;
                        pl.SetTextString("Vote - Yes");
                    }
                    if (temp.Contains("No") && pl.Path != null && pl.Path.ToLower().IndexOf("legend") != -1)
                    {
                        pl.PE.Fill = Color.Gold;
                        pl.SetTextString("Vote - No");
                    }
                }
            }

            legendItems.Clear();
            defaultFillBrushes.Clear();
            legendText.Clear();

            foreach (Primitive p in e.SceneGraph)
            {
                if (p is Box && p.Path != null && p.Path.ToLower().IndexOf("legend") != -1 && p.Row != -1 && p.Column != -1)
                {
                    legendItems.Add(p as Box);
                    defaultFillBrushes.Add(p.PE.Fill);
                }

                if (p is Text && p.Path != null && p.Path.ToLower().IndexOf("legend") != -1)
                {
                    legendText.Add(p as Text);
                }
            }


            
        }

        private void ultraChart1_MouseMove(object sender, MouseEventArgs e)
        {
            if (legendItems.Where(p => p.rect.X < e.Location.X && e.Location.X < p.rect.X + p.rect.Width && p.rect.Y < e.Location.Y && p.rect.Y + p.rect.Height > e.Location.Y).Count() > 0)
            {
                Box it = legendItems.Where(p => p.rect.X < e.Location.X && e.Location.X < p.rect.X + p.rect.Width && p.rect.Y < e.Location.Y && p.rect.Y + p.rect.Height > e.Location.Y).First();

                if (it != null)
                {
                    int index = legendItems.IndexOf(it);
                    Graphics gr = ultraChart1.CreateGraphics();
                    gr.DrawRectangle(new Pen(Brushes.Black), new Rectangle(it.rect.X + 9, it.rect.Y - 11, 82, 16));
                    gr.FillRectangle(Brushes.WhiteSmoke, new Rectangle(it.rect.X + 10, it.rect.Y - 10, 80, 15));
                    gr.DrawString(legendText[index].GetTextString(), new System.Drawing.Font("Ariel", 8F), Brushes.Black, new PointF(it.rect.X + 10, it.rect.Y - 10));
                }
            }
            else
            {
                ultraChart1.Refresh();
            }
        }
    }
}
